@@ -61,8 +61,11 @@ MainWindow::MainWindow(QWidget *parent, const Session& session) : KXmlGuiWindow(
     setupCentralWidget();
     setupStatusBar();
     setupActions();
-    // TODO: find a better fix for #351746 than QSize(0, 0);
-    setupGUI(QSize(0, 0), KXmlGuiWindow::Default, QStringLiteral("kronometerui.rc"));
+    setupGUI(KXmlGuiWindow::Default, QStringLiteral("kronometerui.rc"));
+
+    // TODO: find a better fix for #351746
+    resize(minimumSizeHint());
+
     slotInactive();    // inactive state is the default
     loadSettings();
 
